DynamicPolynomialF

Struct DynamicPolynomialF 

pub struct DynamicPolynomialF<F: PrimeField> {
    pub coeffs: Vec<F>,
}
Polynomials of dynamic degree. The implementation is tailored to work with random finite fields. To be used in UAIR and PIOP where ZIP+ degree bound is not observed anymore.

Note that operations involving dynamic polynomials do not trim leading zeros meaning one can end up with unequal objects of the type DynamicPoly<F> that represent equal polynomials, therefore trim has to be called before checking equality.

Fields

coeffs: Vec<F>

Implementations

Source

impl<F: PrimeField> DynamicPolynomialF<F>

pub fn new_trimmed(coeffs: impl AsRef<[F]>) -> Self

Create a new polynomial with the given coefficients.

pub fn new(coeffs: impl AsRef<[F]>) -> Self

pub fn degree(&self) -> Option<usize>

pub fn trim(&mut self)

pub fn constant_poly(a: F) -> Self